<template>
  <div class="sewers-search" v-if="gdVisible">
    <div class="panel-title">{{ title }}</div>
    <el-tabs v-model="activeName" @tab-click="handleClick">
      <el-tab-pane label="查询" name="first">
        <div class="search-panel ">
          <el-form ref="form" :model="form" label-width="90px" class="search-form">
            <el-form-item label="设施类型：" size="mini" class="search-panel-item">
              <el-select style="width: 100%" v-model="form.pipelineType" @change="handlePipelineType"
                         :popper-class="'select-down'">
                <el-option
                    v-for="item in items"
                    :key="item.code"
                    :label="item.name"
                    :value="item.name">
                </el-option>
              </el-select>
            </el-form-item>
            <el-form-item :label="form.pipelineType+'：'" size="mini">
              <el-select style="width: 100%" v-model="form.dataType" value-key="code" :popper-class="'select-down'" @change="handleDataType" >
                <el-option
                      v-for="item in subItems"
                      :key="item.code"
                      :label="item.name"
                      :value="item">
              </el-option>
              </el-select>
            </el-form-item>
            <div class="rightButtonSearch">
              <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
              <el-button class="el-icon-search" @click="handleSearch"></el-button>
            </div>
          </el-form>
        </div>
        <el-scrollbar style="height:413px;">
          <div class="environmental-risk-list" v-for="(item,index) in list" :key="index" :class="activeNum==index?'hover':''">
            <img class="state" :src="getImgSrc()" style="background: none"/>
            <div>
              <h3 @click="handleLocation(item,index)">{{ item.properties.pipename }}</h3>
              <p>所属企业：<span>{{ item.properties.orgcode }}</span>
              <p>设施类型：<span>{{ item.properties.teetype }}</span>
               <el-button v-if="fuShuSheShiShow" class="rt btn00fff6" size="mini" style="margin-right: 0.04rem;" @click="btnAffiliatedFacilities(item,index)" >附属设施</el-button>
              </p>
            </div>
          </div>
        </el-scrollbar>
        <el-card class="footer-page" v-if="total > 10">
          <el-pagination
              small
              @current-change="handlePage"
              :page-size=pageSize
              layout="prev, pager, next"
              :total=total
              :current-page=current
              class="warnPagination"
          >
          </el-pagination>
        </el-card>
      </el-tab-pane>
      <el-tab-pane label="分析" name="second">
        <SewersAnalysis></SewersAnalysis>
      </el-tab-pane>
      <el-tab-pane label="历史" name="third">
        <SewersHistory></SewersHistory>
      </el-tab-pane>
    </el-tabs>
    <!-- 附属设施面板 -->
    <affiliated-facilities :facilitiesParameter="facilitiesParameter"  v-if="fuShuSheShiShow" ></affiliated-facilities>
  </div>
</template>

<script>
import { LayerPipeLines } from '@src/conf/layers/LayerPipeLines'
import { LayerFsss } from '@src/conf/layers/LayerFsss'
import { LayerHbss } from '@src/conf/layers/LayerHbss'
import { LayerPk } from '@src/conf/layers/LayerPk'
import { LayerArea } from '@src/conf/layers/LayerArea'

import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'

import AffiliatedFacilities from '@components/BaseNav/pipeline/AffiliatedFacilities'

// 引入组件内容
import SewersAnalysis from '@components/panel/topicSearch/SewersSelect/SewersAnalysis'
import SewersHistory from '@components/panel/topicSearch/SewersSelect/SewersHistory'

export default {
  name: 'SewersSearch',
  components: {
    SewersAnalysis,
    SewersHistory,
    AffiliatedFacilities
  },
  data () {
    return {
      activeName: 'first',
      gdVisible: true,
      list: [],
      items: [LayerPipeLines, LayerFsss, LayerHbss, LayerPk, LayerArea],
      subItems: LayerPipeLines.layers,
      pageSize: 10,
      total: 0,
      form: {
        pipelineType: '管线',
        dataType: '',
        keyword: ''
      },
      // pageSize: 10,
      // current: 1,
      isWaybillHover: true,
      isRouteHover: false,
      facilitiesParameter: null,
      fuShuSheShiShow: true,
      fuShuSheShiPanelShow: true,
      activeNum: -1,
      wfsHelper: null
    }
  },
  props: ['title'],
  methods: {
    getImgSrc () {
      const icon = this.form.dataType.icon
      return icon ? 'assets/images/map/' + icon : ''
    },
    handleClick (tab, event) {
      console.log(tab, event)
    },
    handlePage (page) {
      this.wfsHelper.setPage(page)
      this.handleSearch()
    },
    // 设施类型筛选
    handlePipelineType (val) {
      this.list = []
      // debugger
      for (let i = 0; i < this.items.length; i++) {
        const item = this.items[i]
        if (val === item.name) {
          this.subItems = item.layers
          return
        }
      }
    },
    handleDataType () {
      this.list = []
    },
    async handleSearch () {
      // console.log(this.form.dataType.sname, this.form.keyword)
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在管网还没区分开类型，后面改
      this.wfsHelper.setTypeName([this.form.dataType.typeName])
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      // const _this = this
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.total = res.totalFeatures
        this.list = res.features
      }
    },
    handleLocation (val, index) {
      console.log(val)
      // console.log(val)
      this.activeNum = index
      // layer && layer.openPopup()
      window.layerFactory.flyByFeature(val, this.form.dataType.code)
    },
    btnAffiliatedFacilities (val, index) {
      this.activeNum = index
      this.facilitiesParameter = val
      // 判断选择是否是管线，如果是则显示《附属设施》弹框
      if (this.form.pipelineType === '管线') {
        this.fuShuSheShiShow = true
      } else {
        this.fuShuSheShiShow = false
      }
      window.layerFactory.flyByFeature(val, this.form.dataType.code)
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  }
}
</script>

<style lang="less" scoped>

</style>
